/*
 * Project name:
     UART2 (Simple usage of UART2 module library functions)
 * Copyright:
     (c) mikroElektronika, 2008.
 * Revision History:
     20081218:
       - initial release;
 * Description:
     This code demonstrates how to use UART2 library routines. Upon receiving
     data via RS232, MCU immediately sends it back to the sender.
 * Test configuration:
     MCU:             P18F8520
                      http://ww1.microchip.com/downloads/en/DeviceDoc/39609b.pdf
     Dev.Board:       BIGPIC6
                      http://www.mikroe.com/en/tools/bigpic6/
     Oscillator:      HS, 10.0 MHz
     Ext. Modules:    -
     SW:              mikroC PRO for PIC
                      http://www.mikroe.com/en/compilers/mikroc/pro/pic/
 * NOTES:
     - Turn on UART2 switches SW12.3 and SW12.4 (board specific).
*/

char uart_rd;

void main() {

  ADCON1 |= 0x0F;                 // Configure AN pins as digital
  CMCON  |= 7;                    // Disable comparators

  UART2_Init(9600);               // Initialize UART module at 9600 bps
  Delay_ms(100);                  // Wait for UART module to stabilize

  UART2_Write_Text("Start");
  UART2_Write(10);                // Line feed
  UART2_Write(13);                // Carriage return

  while (1) {                     // Endless loop
   if (UART2_Data_Ready()) {      // If data is received,
     uart_rd = UART2_Read();      //   read the received data,
     UART2_Write(uart_rd);        //   and send data via UART
    }
  }
}
